@@ -130,8 +130,8 @@ class VideoDownloader:
 
             # --- Registry shortcut
             cached = self.registry.get_video_info(video_url, force_refresh=self.force_refresh)
-            if cached and cached.get("file_path") and os.path.isfile(cached["file_path"]):
-                logger.info(f"[VideoDownloader] Found cached file: {cached['file_path']}")
+            if cached and cached.get("video_path") and os.path.isfile(cached["video_path"]):
+                logger.info(f"[VideoDownloader] Found cached file: {cached['video_path']}")
                 return cached
 
             tmp_outtmpl = os.path.join(self.download_directory, "%(id)s.%(ext)s")
@@ -154,7 +154,7 @@ class VideoDownloader:
                     final_path = os.path.join(dirbase, f"video{ext or '.mp4'}")
                     if temp_path != final_path and os.path.isfile(temp_path):
                         shutil.move(temp_path, final_path)
-                    info["file_path"] = final_path
+                    info["video_path"] = final_path
 
                     # --- Write info.json
                     info_path = os.path.join(dirbase, "info.json")
